Skip to contents

Calculate naive COI

Usage

calculate_naive_coi(data)

Arguments

data

List of lists of numeric vectors, where each list element is a collection of observations across samples at a single genetic locus.

Value

Numeric vector with one naive COI estimate per sample.

Details

Estimates the complexity of infection using a naive approach that chooses the highest number of observed alleles.

Examples

calculate_naive_coi(simulated_data$data)
#>   [1] 2 4 4 5 7 4 4 5 4 3 4 5 5 2 5 6 4 4 6 6 5 5 3 3 4 6 4 4 7 5 3 3 5 2 6 6 4
#>  [38] 6 3 3 4 7 5 5 6 5 4 3 4 5 5 4 6 4 4 5 5 4 4 6 3 4 6 3 3 6 5 8 7 7 4 5 1 2
#>  [75] 4 5 1 4 4 3 5 5 1 5 3 6 4 4 4 4 4 6 4 5 7 6 5 6 5 5