MCMC results from using the packaged simulated data and calling run_mcmc()
Source: R/data.R
mcmc_results.RdMCMC results from using the packaged simulated data and calling run_mcmc()
Format
A list as returned by run_mcmc() on simulated_data: a single
chain with 1000 burnin and 1000 sampling iterations, using 80 parallel
tempering replicas with adaptive temperatures. The mcmc_demo vignette
shows the call.