Skip to contents

Simulate observed genotypes

Usage

simulate_observed_genotype(
  true_genotypes,
  epsilon_pos,
  epsilon_neg,
  missingness
)

Arguments

true_genotypes

a list of numeric vectors that are input to sim_observed_allele

epsilon_pos

expected number of false positives

epsilon_neg

expected number of false negatives

missingness

probability of data being missing

Value

List the same length as true_genotypes, each element a binary vector of observed alleles as returned by simulate_observed_allele().

Details

Simulate the observation process across a list of observation vectors

Examples

true_genotypes <- list(c(1, 0, 1), c(0, 2, 0))
simulate_observed_genotype(
  true_genotypes,
  epsilon_pos = 0.01, epsilon_neg = 0.1, missingness = 0
)
#> [[1]]
#> [1] 1 0 1
#> 
#> [[2]]
#> [1] 0 1 0
#>