Skip to contents

Summarize epsilon_neg

Usage

summarize_epsilon_neg(
  mcmc_results,
  lower_quantile = 0.025,
  upper_quantile = 0.975,
  merge_chains = TRUE
)

Arguments

mcmc_results

Result of calling run_mcmc()

lower_quantile

The lower quantile of the posterior distribution to return

upper_quantile

The upper quantile of the posterior distribution to return

merge_chains

boolean indicating that all chain results should be merged

Value

Data frame with one row per sample (per chain if merge_chains is FALSE) giving posterior quantiles and mean of the false negative rate.

Details

Summarize epsilon negative results from MCMC. Returns a dataframe that contains summaries of the posterior distribution of epsilon negative for each biological sample.

Examples

eps_neg_summary <- summarize_epsilon_neg(mcmc_results)
head(eps_neg_summary)
#>   sample_id post_eps_neg_lower post_eps_neg_med post_eps_neg_upper
#> 1        S1       4.329687e-16     3.638371e-05         0.03496541
#> 2        S2       1.058564e-18     1.181242e-05         0.03519108
#> 3        S3       2.237441e-17     4.025592e-05         0.02810528
#> 4        S4       5.288433e-19     1.865621e-05         0.02179045
#> 5        S5       2.697471e-19     3.986907e-06         0.02012594
#> 6        S6       5.027042e-19     3.963974e-06         0.03902359
#>   post_eps_neg_mean
#> 1       0.006043775
#> 2       0.004259470
#> 3       0.003050770
#> 4       0.002375168
#> 5       0.001869910
#> 6       0.003387904