Skip to contents

Summarize epsilon_pos

Usage

summarize_epsilon_pos(
  mcmc_results,
  lower_quantile = 0.025,
  upper_quantile = 0.975,
  merge_chains = TRUE
)

Arguments

mcmc_results

Result of calling run_mcmc()

lower_quantile

The lower quantile of the posterior distribution to return

upper_quantile

The upper quantile of the posterior distribution to return

merge_chains

boolean indicating that all chain results should be merged

Value

Data frame with one row per sample (per chain if merge_chains is FALSE) giving posterior quantiles and mean of the false positive rate.

Details

Summarize epsilon positive results from MCMC. Returns a dataframe that contains summaries of the posterior distribution of epsilon positive for each biological sample.

Examples

eps_pos_summary <- summarize_epsilon_pos(mcmc_results)
head(eps_pos_summary)
#>   sample_id post_eps_pos_lower post_eps_pos_med post_eps_pos_upper
#> 1        S1       8.497232e-20     1.960169e-06         0.01305732
#> 2        S2       2.404102e-17     9.035961e-06         0.01093046
#> 3        S3       6.649455e-22     3.432700e-06         0.02175966
#> 4        S4       4.492639e-20     2.152755e-05         0.01661785
#> 5        S5       1.126230e-16     1.425806e-05         0.03486907
#> 6        S6       1.142849e-20     3.146027e-05         0.01907917
#>   post_eps_pos_mean
#> 1       0.001419447
#> 2       0.001600433
#> 3       0.002461778
#> 4       0.001781988
#> 5       0.003174385
#> 6       0.002067003