Calculate naive COI offset
Usage
calculate_naive_coi_offset(data, offset)
Arguments
- data
List of lists of numeric vectors, where each list
element is a collection of observations across samples at a
single genetic locus.
- offset
Numeric offset – n'th highest number of observed alleles
Value
Numeric vector with one naive COI estimate per sample.
Details
Estimates the complexity of infection using a naive approach
that chooses the n'th highest number of observed alleles.
Examples
calculate_naive_coi_offset(simulated_data$data, offset = 2)
#> [1] 2 4 4 5 6 4 3 5 4 3 4 4 5 2 5 5 4 3 5 5 4 4 3 3 4 5 4 3 6 4 3 3 5 2 5 6 4
#> [38] 5 3 3 4 6 5 5 6 5 4 3 4 5 5 4 6 4 3 4 5 3 4 5 3 4 5 3 2 5 5 7 6 5 4 4 1 2
#> [75] 4 5 1 4 4 3 5 4 1 4 3 5 4 4 4 4 4 5 4 4 7 5 5 6 5 5